A(n almost) transparent replacement for yapsy made for python 3.4+.

I kept having issues with Yapsy so here we are. No complaints with the
authors of Yapsy though, they never got to hear my anguish because I was
on a tight schedule to finish a project. Perhaps I just didn't get how it was supposed to work. You might have better luck.

In any case this is a quick and very basic implementation of a plugin framework. Documentation may follow (check Yapsy documentation for now) or I may dig deeper into Yapsy to solve the issues I had if they are compatible with how I would like the plugin framework to act.

Since I already had the logic in place for the existing Yapsy methods I have used identical names, including their intended functionality. This is done even if unnecessary or overkill in this basic package. Thus it should be easy to go back to Yapsy if that makes sense at a later point.

Note: Alpha for now - YMMV.

To install: ``pip install blasy``
